Additional Resources
======================

.. hint::
   Would like to add something? Join us by contributing (`see this tutorial <https://neurokit2.readthedocs.io/en/latest/tutorials/contributing.html>`_).


General Neuroimaging
-----------------------

- `Seven quick tips for analysis scripts in neuroimaging <https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1007358>`_ (van Vliet, 2020).
- `Neuroimaging tutorials and resources <https://.github.io/tutorials-and-resources/>`_



ECG 
----

- `Improving Data Quality: ECG <https://support.mindwaretech.com/2017/12/improving-data-quality-ecg/>`_
- `Understanding ECG waves <https://ecgwaves.com/topic/ecg-normal-p-wave-qrs-complex-st-segment-t-wave-j-point/>`_
- `Analysing a Noisy ECG Signal <https://github.com/paulvangentcom/heartrate_analysis_python/blob/master/examples/5_noisy_ECG/Analysing_Noisy_ECG.ipynb>`_
- `All About HRV Part 4: Respiratory Sinus Arrhythmia <https://support.mindwaretech.com/2017/09/all-about-hrv-part-4-respiratory-sinus-arrhythmia/>`_


EDA 
----

- `Improving Data Quality: EDA <https://support.mindwaretech.com/2017/12/improving-data-quality-eda/>`_
- `All About EDA Part 1: Introduction to Electrodermal Activity <https://support.mindwaretech.com/2017/12/all-about-eda-part-1-introduction-to-electrodermal-activity/>`_
- `All About EDA Part 2: Components of Skin Conductance <https://support.mindwaretech.com/2018/04/all-about-eda-part-2-components-of-skin-conductance/>`_
- `Skin Conductance Response – What it is and How to Measure it <https://imotions.com/blog/skin-conductance-response/>`_





EEG
----

- `Electroencephalogram (EEG) Recording Protocol (Farrens et al., 2019) <https://protocolexchange.researchsquare.com/article/pex-779/v2>`_
- `Compute the average bandpower of an EEG signal <https://raphaelvallat.com/bandpower.html>`_
